//----------------------------------------------------------------------------//

/*
 * Copyright (c) 2009 Sony Pictures Imageworks Inc
 *
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * Redistributions of source code must retain the above copyright
 * notice, this list of conditions and the following disclaimer.
 * Redistributions in binary form must reproduce the above copyright
 * notice, this list of conditions and the following disclaimer in the
 * documentation and/or other materials provided with the
 * distribution.  Neither the name of Sony Pictures Imageworks nor the
 * names of its contributors may be used to endorse or promote
 * products derived from this software without specific prior written
 * permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
 * FOR A PARTICULAR PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL THE
 * COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
 * OF THE POSSIBILITY OF SUCH DAMAGE.
 */

//----------------------------------------------------------------------------//

#ifndef _INCLUDED_Field3D_StdMathLib_H_
#define _INCLUDED_Field3D_StdMathLib_H_

// The version can reliably be found in this header file from OpenEXR,
// for both 2.x and 3.x:
#include <OpenEXR/OpenEXRConfig.h>
#define COMBINED_OPENEXR_VERSION ((10000*OPENEXR_VERSION_MAJOR) + \
                                  (100*OPENEXR_VERSION_MINOR) + \
                                  OPENEXR_VERSION_PATCH)

// There's just no easy way to have an `#include` that works in both
// cases, so we use the version to switch which set of include files we
// use.
#if COMBINED_OPENEXR_VERSION >= 20599 /* 2.5.99: pre-3.0 */
#   include <Imath/ImathBox.h>
#   include <Imath/ImathBoxAlgo.h>
#   include <Imath/ImathColor.h>
#   include <Imath/ImathMatrix.h>
#   include <Imath/ImathMatrixAlgo.h>
#   include <Imath/ImathPlane.h>
#   include <Imath/ImathRandom.h>
#   include <Imath/ImathRoots.h>
#   include <Imath/ImathVec.h>
#   include <Imath/half.h>
#else
    // OpenEXR 2.x, use the old locations
#   include <OpenEXR/ImathBox.h>
#   include <OpenEXR/ImathBoxAlgo.h>
#   include <OpenEXR/ImathColor.h>
#   include <OpenEXR/ImathHalfLimits.h>
#   include <OpenEXR/ImathMatrix.h>
#   include <OpenEXR/ImathMatrixAlgo.h>
#   include <OpenEXR/ImathPlane.h>
#   include <OpenEXR/ImathRandom.h>
#   include <OpenEXR/ImathRoots.h>
#   include <OpenEXR/ImathVec.h>
#   include <OpenEXR/half.h>
#endif
//----------------------------------------------------------------------------//

#include "ns.h"

FIELD3D_NAMESPACE_OPEN

//----------------------------------------------------------------------------//

typedef ::half               half;
typedef Imath::V2i           V2i;
typedef Imath::V2d           V2d;
typedef Imath::C3f           C3f;
typedef Imath::V3i           V3i;
typedef Imath::Vec3<half>    V3h;
typedef Imath::V3f           V3f;
typedef Imath::V3d           V3d;
typedef Imath::Box3i         Box3i;
typedef Imath::Box3d         Box3d;
typedef Imath::Line3d        Ray3d;
typedef Imath::M44d          M44d;
typedef Imath::Plane3d       Plane3d;

#define FIELD3D_BOX_T        Imath::Box
#define FIELD3D_MTX_T        Imath::Matrix44
#define FIELD3D_VEC3_T       Imath::Vec3

#define FIELD3D_CLIP         Imath::clip
#define FIELD3D_LERP         Imath::lerp
#define FIELD3D_LERPFACTOR   Imath::lerpfactor
#define FIELD3D_EXTRACT_SHRT Imath::extractSHRT

#define FIELD3D_RAND48       Imath::Rand48

//----------------------------------------------------------------------------//

FIELD3D_NAMESPACE_HEADER_CLOSE

//----------------------------------------------------------------------------//

#endif // Include guard
